# enShroud

![](/img/enShroud.png)

## Introduction

A steganography tool to hide secret texts in white space.

## Usage:

- To encode:

```python
python3 enShroud.py -e -p PATH_TO_TEXT_FILE -o PATH_TO_OUTPUT -s "SECRET_MESSAGE_IN_QUOTES"
```

- To decode:

```python
python3 enShroud.py -d -p PATH_TO_TEXT_FILE
```
